nlptools.DataDownload
=====================

.. automodule:: nlptools.DataDownload

Classes
-------
.. autoclass::nlptools.DataDownload.downloader

Functions
---------
.. autoFunction::nlptools.DataDownload.downloader.download_file
.. autoFunction::nlptools.DataDownload.downloader.download_files




